@@ -21,16 +21,16 @@
 
 #' Class 'mic'
 #'
-#' This transforms a vector to a new class \code{mic}, which is an ordered factor with valid MIC values as levels. Invalid MIC values will be translated as \code{NA} with a warning.
+#' This transforms a vector to a new class [`mic`], which is an ordered [`factor`] with valid MIC values as levels. Invalid MIC values will be translated as `NA` with a warning.
 #' @rdname as.mic
 #' @param x vector
 #' @param na.rm a logical indicating whether missing values should be removed
-#' @details Interpret MIC values as RSI values with \code{\link{as.rsi}}. It supports guidelines from EUCAST and CLSI.
-#' @return Ordered factor with new class \code{mic}
-#' @keywords mic
+#' @details To interpret MIC values as RSI values, use [as.rsi()] on MIC values. It supports guidelines from EUCAST and CLSI.
+#' @return Ordered [`factor`] with new class [`mic`]
+#' @aliases mic
 #' @export
 #' @importFrom dplyr %>%
-#' @seealso \code{\link{as.rsi}}
+#' @seealso [as.rsi()]
 #' @inheritSection AMR Read more on our website!
 #' @examples
 #' mic_data <- as.mic(c(">=32", "1.0", "1", "1.00", 8, "<=0.128", "8", "16", "16"))
@@ -51,8 +51,6 @@
 #'
 #' plot(mic_data)
 #' barplot(mic_data)
-#' 
-#' library(clean)
 #' freq(mic_data)
 as.mic <- function(x, na.rm = FALSE) {
   if (is.mic(x)) {
@@ -97,98 +95,15 @@ as.mic <- function(x, na.rm = FALSE) {
     x[x.bak != "" & x == ""] <- "invalid"
 
     # these are allowed MIC values and will become factor levels
-    lvls <- c("<0.001", "<=0.001", "0.001", ">=0.001", ">0.001",
-              "<0.002", "<=0.002", "0.002", ">=0.002", ">0.002",
-              "<0.003", "<=0.003", "0.003", ">=0.003", ">0.003",
-              "<0.004", "<=0.004", "0.004", ">=0.004", ">0.004",
-              "<0.005", "<=0.005", "0.005", ">=0.005", ">0.005",
-              "<0.006", "<=0.006", "0.006", ">=0.006", ">0.006",
-              "<0.007", "<=0.007", "0.007", ">=0.007", ">0.007",
-              "<0.008", "<=0.008", "0.008", ">=0.008", ">0.008",
-              "<0.009", "<=0.009", "0.009", ">=0.009", ">0.009",
-              "<0.01", "<=0.01", "0.01", ">=0.01", ">0.01",
-              "<0.012", "<=0.012", "0.012", ">=0.012", ">0.012",
-              "<0.0125", "<=0.0125", "0.0125", ">=0.0125", ">0.0125",
-              "<0.016", "<=0.016", "0.016", ">=0.016", ">0.016",
-              "<0.019", "<=0.019", "0.019", ">=0.019", ">0.019",
-              "<0.02", "<=0.02", "0.02", ">=0.02", ">0.02",
-              "<0.023", "<=0.023", "0.023", ">=0.023", ">0.023",
-              "<0.025", "<=0.025", "0.025", ">=0.025", ">0.025",
-              "<0.028", "<=0.028", "0.028", ">=0.028", ">0.028",
-              "<0.03", "<=0.03", "0.03", ">=0.03", ">0.03",
-              "<0.031", "<=0.031", "0.031", ">=0.031", ">0.031",
-              "<0.032", "<=0.032", "0.032", ">=0.032", ">0.032",
-              "<0.038", "<=0.038", "0.038", ">=0.038", ">0.038",
-              "<0.04", "<=0.04", "0.04", ">=0.04", ">0.04",
-              "<0.047", "<=0.047", "0.047", ">=0.047", ">0.047",
-              "<0.05", "<=0.05", "0.05", ">=0.05", ">0.05",
-              "<0.054", "<=0.054", "0.054", ">=0.054", ">0.054",
-              "<0.06", "<=0.06", "0.06", ">=0.06", ">0.06",
-              "<0.0625", "<=0.0625", "0.0625", ">=0.0625", ">0.0625",
-              "<0.063", "<=0.063", "0.063", ">=0.063", ">0.063",
-              "<0.064", "<=0.064", "0.064", ">=0.064", ">0.064",
-              "<0.075", "<=0.075", "0.075", ">=0.075", ">0.075",
-              "<0.08", "<=0.08", "0.08", ">=0.08", ">0.08",
-              "<0.09", "<=0.09", "0.09", ">=0.09", ">0.09",
-              "<0.094", "<=0.094", "0.094", ">=0.094", ">0.094",
-              "<0.095", "<=0.095", "0.095", ">=0.095", ">0.095",
-              "<0.1", "<=0.1", "0.1", ">=0.1", ">0.1",
-              "<0.12", "<=0.12", "0.12", ">=0.12", ">0.12",
-              "<0.125", "<=0.125", "0.125", ">=0.125", ">0.125",
-              "<0.128", "<=0.128", "0.128", ">=0.128", ">0.128",
-              "<0.15", "<=0.15", "0.15", ">=0.15", ">0.15",
-              "<0.16", "<=0.16", "0.16", ">=0.16", ">0.16",
-              "<0.17", "<=0.17", "0.17", ">=0.17", ">0.17",
-              "<0.18", "<=0.18", "0.18", ">=0.18", ">0.18",
-              "<0.19", "<=0.19", "0.19", ">=0.19", ">0.19",
-              "<0.2", "<=0.2", "0.2", ">=0.2", ">0.2",
-              "<0.23", "<=0.23", "0.23", ">=0.23", ">0.23",
-              "<0.25", "<=0.25", "0.25", ">=0.25", ">0.25",
-              "<0.256", "<=0.256", "0.256", ">=0.256", ">0.256",
-              "<0.28", "<=0.28", "0.28", ">=0.28", ">0.28",
-              "<0.3", "<=0.3", "0.3", ">=0.3", ">0.3",
-              "<0.32", "<=0.32", "0.32", ">=0.32", ">0.32",
-              "<0.35", "<=0.35", "0.35", ">=0.35", ">0.35",
-              "<0.36", "<=0.36", "0.36", ">=0.36", ">0.36",
-              "<0.38", "<=0.38", "0.38", ">=0.38", ">0.38",
-              "<0.47", "<=0.47", "0.47", ">=0.47", ">0.47",
-              "<0.5", "<=0.5", "0.5", ">=0.5", ">0.5",
-              "<0.512", "<=0.512", "0.512", ">=0.512", ">0.512",
-              "<0.64", "<=0.64", "0.64", ">=0.64", ">0.64",
-              "<0.73", "<=0.73", "0.73", ">=0.73", ">0.73",
-              "<0.75", "<=0.75", "0.75", ">=0.75", ">0.75",
-              "<0.8", "<=0.8", "0.8", ">=0.8", ">0.8",
-              "<0.94", "<=0.94", "0.94", ">=0.94", ">0.94",
-              "<1", "<=1", "1", ">=1", ">1",
-              "<1.5", "<=1.5", "1.5", ">=1.5", ">1.5",
-              "<2", "<=2", "2", ">=2", ">2",
-              "<3", "<=3", "3", ">=3", ">3",
-              "<4", "<=4", "4", ">=4", ">4",
-              "<5", "<=5", "5", ">=5", ">5",
-              "<6", "<=6", "6", ">=6", ">6",
-              "<7", "<=7", "7", ">=7", ">7",
-              "<8", "<=8", "8", ">=8", ">8",
-              "<10", "<=10", "10", ">=10", ">10",
-              "<12", "<=12", "12", ">=12", ">12",
-              "<16", "<=16", "16", ">=16", ">16",
-              "<20", "<=20", "20", ">=20", ">20",
-              "<24", "<=24", "24", ">=24", ">24",
-              "<32", "<=32", "32", ">=32", ">32",
-              "<40", "<=40", "40", ">=40", ">40",
-              "<48", "<=48", "48", ">=48", ">48",
-              "<64", "<=64", "64", ">=64", ">64",
-              "<80", "<=80", "80", ">=80", ">80",
-              "<96", "<=96", "96", ">=96", ">96",
-              "<128", "<=128", "128", ">=128", ">128",
-              "129",
-              "<160", "<=160", "160", ">=160", ">160",
-              "<256", "<=256", "256", ">=256", ">256",
-              "257",
-              "<320", "<=320", "320", ">=320", ">320",
-              "<512", "<=512", "512", ">=512", ">512",
-              "513",
-              "<1024", "<=1024", "1024", ">=1024", ">1024",
-              "1025")
+    ops <- c("<", "<=", "", ">=", ">")
+    lvls <- c(c(t(sapply(ops, function(x) paste0(x, "0.00", 1:9)))),
+              unique(c(t(sapply(ops, function(x) paste0(x, sort(as.double(paste0("0.0", 
+                                                                                 sort(c(1:99, 125, 128, 256, 512, 625)))))))))),
+              unique(c(t(sapply(ops, function(x) paste0(x, sort(as.double(paste0("0.", 
+                                                                                 c(1:99, 125, 128, 256, 512))))))))),
+              c(t(sapply(ops, function(x) paste0(x, sort(c(1:9, 1.5)))))),
+              c(t(sapply(ops, function(x) paste0(x, c(10:98)[9:98 %% 2 == TRUE])))),
+              c(t(sapply(ops, function(x) paste0(x, sort(c(2 ^ c(7:10), 80 * c(2:12))))))))
 
     na_before <- x[is.na(x) | x == ""] %>% length()
     x[!x %in% lvls] <- NA
