@@ -22,13 +22,13 @@
 context("kurtosis.R")
 
 test_that("kurtosis works", {
-  expect_equal(kurtosis(septic_patients$age),
+  expect_equal(kurtosis(example_isolates$age),
                3.549319,
                tolerance = 0.00001)
-  expect_equal(unname(kurtosis(data.frame(septic_patients$age))),
+  expect_equal(unname(kurtosis(data.frame(example_isolates$age))),
                3.549319,
                tolerance = 0.00001)
-  expect_equal(kurtosis(matrix(septic_patients$age)),
+  expect_equal(kurtosis(matrix(example_isolates$age)),
                3.549319,
                tolerance = 0.00001)
 })
