@@ -22,7 +22,7 @@
 context("like.R")
 
 test_that("`like` works", {
-  expect_true(suppressWarnings("test" %like% c("^t", "^s")))
+  expect_true(sum("test" %like% c("^t", "^s")) == 1)
   expect_true("test" %like% "test")
   expect_true("test" %like% "TEST")
   expect_true(as.factor("test") %like% "TEST")
