@@ -22,6 +22,9 @@
 context("rsi.R")
 
 test_that("rsi works", {
+  
+  skip_on_cran()
+  
   expect_true(as.rsi("S") < as.rsi("I"))
   expect_true(as.rsi("I") < as.rsi("R"))
   expect_true(as.rsi("R") > as.rsi("S"))
@@ -41,12 +44,12 @@ test_that("rsi works", {
                                                "-Sum R" = "1",
                                                "-Sum I" = "0"))
 
-  expect_identical(as.logical(lapply(septic_patients, is.rsi.eligible)),
-                   rep(FALSE, length(septic_patients)))
+  expect_identical(as.logical(lapply(example_isolates, is.rsi.eligible)),
+                   rep(FALSE, length(example_isolates)))
 
   library(dplyr)
   # 40 rsi columns
-  expect_equal(septic_patients %>%
+  expect_equal(example_isolates %>%
                  mutate_at(vars(PEN:RIF), as.character) %>%
                  lapply(is.rsi.eligible) %>%
                  as.logical() %>%
@@ -56,20 +59,23 @@ test_that("rsi works", {
 })
 
 test_that("mic2rsi works", {
+  
+  skip_on_cran()
+  
   expect_equal(as.character(
     as.rsi(x = as.mic(0.125),
-                      mo = "B_STRPT_PNE",
+                      mo = "B_STRPT_PNMN",
                       ab = "AMX",
                       guideline = "EUCAST")),
     "S")
   expect_equal(as.character(
     as.rsi(x = as.mic(4),
-           mo = "B_STRPT_PNE",
+           mo = "B_STRPT_PNMN",
            ab = "AMX",
            guideline = "EUCAST")),
     "R")
 
-  expect_true(septic_patients %>%
+  expect_true(example_isolates %>%
                 mutate(amox_mic = as.mic(2)) %>%
                 select(mo, amox_mic) %>%
                 as.rsi() %>%
@@ -78,26 +84,29 @@ test_that("mic2rsi works", {
 })
 
 test_that("disk2rsi works", {
+  
+  skip_on_cran()
+  
   expect_equal(as.character(
     as.rsi(x = as.disk(22),
-           mo = "B_STRPT_PNE",
+           mo = "B_STRPT_PNMN",
            ab = "ERY",
            guideline = "CLSI")),
     "S")
   expect_equal(as.character(
     as.rsi(x = as.disk(18),
-           mo = "B_STRPT_PNE",
+           mo = "B_STRPT_PNMN",
            ab = "ERY",
            guideline = "CLSI")),
     "I")
   expect_equal(as.character(
     as.rsi(x = as.disk(10),
-           mo = "B_STRPT_PNE",
+           mo = "B_STRPT_PNMN",
            ab = "ERY",
            guideline = "CLSI")),
     "R")
 
-  expect_true(septic_patients %>%
+  expect_true(example_isolates %>%
                 mutate(amox_disk = as.disk(15)) %>%
                 select(mo, amox_disk) %>%
                 as.rsi(guideline = "CLSI") %>%
